| Title: | Access Updated and Historic Data on Baltimore City, Maryland |
|---|---|
| Description: | This package provides access to a small number of spatial and nonspatial datasets related to Baltimore City, Maryland. |
| Authors: | Eli Pousson [aut, cre] (ORCID: <https://orcid.org/0000-0001-8280-1706>) |
| Maintainer: | Eli Pousson <[email protected]> |
| License: | CC0 |
| Version: | 0.1.0.9000 |
| Built: | 2026-06-05 08:11:16 UTC |
| Source: | https://github.com/elipousson/baltimoredata |
Table from the Baltimore City and Regional Plans Airtable base: https://airtable.com/appC0OOaNJtKU6iHz/shrIb0577rFcNI6vj
baltimore_plansbaltimore_plans
A data frame with 366 rows and 36 variables:
titlePlan title
year_completeYear adopted/completed
year_updateYear updated
date_completeDate (may be approximate)
statusCurrent status
document_urlDocument URL
document_filenameDocument URL
document_cover_filenameDocument URL
site_urlRelated site URL
geographyGeography
document_typeDocument type
programRelated program
prepared_forEntity or entities prepared for
prepared_byEntity or entities prepared by
funded_byEntity or entities funded by
location_namesLocation names
countyCounty name
main_topicMain topic
topicsTopics
name_abbName abbreviation
name_shortShort name
title_altAlternate title for spatial data join
short_descriptionShort document description
document_page_countPage count
document_url_typePage count
status_organizationEntity assigning status
year_statusStatus assignment date
date_statusStatus assignment date
status_regulatoryRegulatory status
sourceDocument source
related_plansRelated plans (typically a preceding plan in a sequence of related plans)
notesNotes
created_dateAirtable record created date/time
last_modifiedAirtable record last modified date/time
record_idAirtable record identifier
plan_area_descPlan area description
This base is an index for community plans, park plans, transportation plans, and related reports or studies for Baltimore City, adjacent counties, and the Baltimore metro area.
The goal is to provide a convenient and accessible reference to information plans include: what the scope and related locations for the plan, when the plan was published or adopted, who prepared the plan, and any programs connected to the plan. This data is the plans table including plans, studies, reports, etc.
Last updated: 2025-05-22
https://airtable.com/appC0OOaNJtKU6iHz/shrIb0577rFcNI6vj
Excerpted from the Baltimore City Entity Reference Airtable base this data includes a listing of agencies, quasi-public agencies, commissions, Mayoral offices, and divisions/offices (incomplete for all agencies).
entity_referenceentity_reference
A data frame with 459 rows and 22 variables:
nameEntity name
name_shortShort name
name_abbAbbreviated name
name_altAlternate name or names
start_yearStart year
end_yearEnd year
statusStatus
levelLevel
entity_urlEntity URL
entity_categoriesEntity categories
entity_typeEntity type
unit_typeUnit type
parent_entityParent entity
supporting_entitySupporting entity
supporting_unitSupporting unit
superseded_bySuperseded by
wikidataWikidata
einEIN
airtable_record_idAirtable record ID
sourcesSources
establishment_referencesEstablishment references (informal)
last_modifiedLast modified date/time
Last updated: 2025-05-22
Note, that the "Baltimore_City_Employee_Residency_by_Agency" source includes identifiers and name-only identifiers that match data found in the "EmployeeSalaries_1" source.
entity_xwalkentity_xwalk
A data frame with 502 rows and 5 variables:
idIdentifier ID
nameIdentifier name
entityEntity name
sourceCrosswalk data source
useUsage status
Last updated: 2025-05-22
An index of digitized atlas maps available from the Maryland State Archives.
msa_atlas_mapsmsa_atlas_maps
A data frame with 786 rows and 17 variables:
source_idMSA identifier
titlePlate or page title
typePlate or page type
sheet_titleSheet title
atlasAtlas reference
file_numberFile number
html_urlURL for HTML gallery page
pdf_urlURL for PDF file
filenameFilename
yearYear (from atlas)
sourceSource (from atlas)
descriptionDescription
locationsLocations (incomplete)
page_numberPage number
gif_urlURL for GIF format file
pdf_right_urlURL for PDF file (right side)
pdf_left_urlURL for PDF file (left side)
https://airtable.com/appLdXzqz0QOXqJTE/shr8NPkZnJzBLjH9r
The Baltimore Neighborhood Indicator Alliance (BNIA) describes the Vital Signs are "data-points compiled from a variety of reliable sources that 'take the pulse' of Baltimore’s neighborhoods." This data set is based on the Vital Signs Data Tables (2010-2018) master Excel file containing all Vital Signs indicators, by year of release.
vital_signs_2010_2018vital_signs_2010_2018
A data frame with 62552 rows and 9 variables:
csa2010Community Statistical Area name
yearVital Signs year
indicatorIndicator name
valueValue of indicator
labelIndicator label
sectionVital Signs section, matching one of eight topic areas
The source file contained the full name of the indicator, values for
Baltimore City and all 55 of the Community Statistical Areas (CSAs). Due to
COVID-19, the publication of the Vital Signs 18 indicators has been staggered
and this data does not yet contain full housing or education data. CSAs with
missing data in the Excel file appear as NA values in this dataset.
https://bniajfi.org/vital_signs/
BNIA Vital Signs Open Data Portal
Labels, definitions, and data sources for the Vital Signs indicators used by the Baltimore Neighborhood Indicators Alliance from 2010 to 2018.
vital_signs_indicatorsvital_signs_indicators
A data frame with 177 rows and 7 variables:
labelIndicator label
sectionVital Signs report section
sourceIndicator data source
normalization_sourceNormalization data source, e.g. Census data for CSA residents
definitionIndicator definition
indicatorIndicator variable name
years_availableYears available
https://bniajfi.org/vital_signs/